emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 5283593: Resurrect earlier fix of resize_frame_wind


From: Martin Rudalics
Subject: [Emacs-diffs] master 5283593: Resurrect earlier fix of resize_frame_windows
Date: Sun, 20 Mar 2016 15:53:35 +0000

branch: master
commit 5283593ced29a2c98e4af3607a68ee7a6d10fcac
Author: Martin Rudalics <address@hidden>
Commit: Martin Rudalics <address@hidden>

    Resurrect earlier fix of resize_frame_windows
    
    * src/window.c (resize_frame_windows): Resurrect earlier fix for
    calculating the number of columns of the minibuffer window which
    was lost in subsequent merges.
---
 src/window.c |   10 ++++++----
 1 files changed, 6 insertions(+), 4 deletions(-)

diff --git a/src/window.c b/src/window.c
index 3cfb6fc..77a43b7 100644
--- a/src/window.c
+++ b/src/window.c
@@ -4064,9 +4064,11 @@ values.  */)
 }
 
 
-/* Resize frame F's windows when number of lines of F is set to SIZE.
-   HORFLAG means resize windows when number of columns of F is set to
-   SIZE.  PIXELWISE means to interpret SIZE as pixels.  */
+/* Resize frame F's windows when F's width or height is set to SIZE.
+   If HORFLAG is zero, F's width was set to SIZE, otherwise its height
+   was set.  SIZE is interpreted in F's canonical character units
+   (a.k.a. "columns" or "lines"), unless PIXELWISE is non-zero, which
+   means to interpret SIZE in pixel units.  */
 void
 resize_frame_windows (struct frame *f, int size, bool horflag, bool pixelwise)
 {
@@ -4167,7 +4169,7 @@ resize_frame_windows (struct frame *f, int size, bool 
horflag, bool pixelwise)
       m = XWINDOW (mini);
       if (horflag)
        {
-         m->total_cols = size;
+         m->total_cols = new_size;
          m->pixel_width = new_pixel_size;
        }
       else



reply via email to

[Prev in Thread] Current Thread [Next in Thread]